@@ -30,7 +30,7 @@ from pymongo.objectid import ObjectId
 from pymongo.dbref import DBRef
 from pymongo.son import SON
 from pymongo.bson import BSON, is_valid, _to_dicts
-from pymongo.errors import UnsupportedTag, InvalidDocument
+from pymongo.errors import UnsupportedTag, InvalidDocument, InvalidStringData
 
 
 class TestBSON(unittest.TestCase):
@@ -132,8 +132,8 @@ class TestBSON(unittest.TestCase):
                          "\x03\x04\x05\x06\x07\x08\x09\x0A\x0B\x00\x00")
 
     def test_null_character_encoding(self):
-        self.assertRaises(InvalidDocument, BSON.from_dict, {"with zero": "hello\x00world"})
-        self.assertRaises(InvalidDocument, BSON.from_dict, {"with zero": u"hello\x00world"})
+        self.assertRaises(InvalidStringData, BSON.from_dict, {"with zero": "hello\x00world"})
+        self.assertRaises(InvalidStringData, BSON.from_dict, {"with zero": u"hello\x00world"})
 
     def test_from_then_to_dict(self):
 
@@ -199,7 +199,7 @@ class TestBSON(unittest.TestCase):
                     f.close()
 
     def test_bad_encode(self):
-        self.assertRaises(UnicodeDecodeError, BSON.from_dict,
+        self.assertRaises(InvalidStringData, BSON.from_dict,
                           {"lalala": '\xf4\xe0\xf0\xe1\xc0 Color Touch'})
 
     def test_overflow(self):
@@ -209,5 +209,9 @@ class TestBSON(unittest.TestCase):
         self.assert_(BSON.from_dict({"x": -9223372036854775808L}))
         self.assertRaises(OverflowError, BSON.from_dict, {"x": -9223372036854775809L})
 
+    def test_tuple(self):
+        self.assertEqual({"tuple": [1, 2]},
+                          BSON.from_dict({"tuple": (1, 2)}).to_dict())
+
 if __name__ == "__main__":
     unittest.main()
